@@ -20,12 +20,12 @@ from sqlalchemy import (
     Table,
     create_engine,
     inspect,
-    select,
     text,
     types,
 )
 from sqlalchemy.dialects import registry  # type: ignore
-from sqlalchemy.engine import Engine, Inspector
+from sqlalchemy.engine import Engine
+from sqlalchemy.engine.reflection import Inspector
 from sqlalchemy.exc import DBAPIError
 from sqlalchemy.ext.declarative import declarative_base
 from sqlalchemy.orm import Session, relationship, sessionmaker
@@ -146,11 +146,17 @@ def test_get_views(engine: Engine) -> None:
     assert views == []
 
     engine.execute(text("create view test as select 1"))
+    engine.execute(
+        text("create schema scheme; create view scheme.schema_test as select 1")
+    )
 
     con = engine.connect()
     views = engine.dialect.get_view_names(con)
     assert views == ["test"]
 
+    views = engine.dialect.get_view_names(con, schema="scheme")
+    assert views == ["schema_test"]
+
 
 @mark.skipif(os.uname().machine == "aarch64", reason="not supported on aarch64")
 def test_preload_extension() -> None:
@@ -225,7 +231,7 @@ def test_table_reflect(session: Session, engine: Engine) -> None:
     user_table = Table("test", meta)
     insp = inspect(engine)
 
-    insp.reflect_table(user_table, None)
+    insp.reflecttable(user_table, None)
 
 
 def test_fetch_df_chunks() -> None:
@@ -255,7 +261,7 @@ def test_binary(session: Session) -> None:
     session.add(a)
     session.commit()
 
-    b: TableWithBinary = session.scalar(select(TableWithBinary))
+    b: TableWithBinary = session.query(TableWithBinary).one()
     assert b.text == "Hello World!"
 
 
@@ -277,8 +283,9 @@ def test_sessions(session: Session) -> None:
     session.add(c)
     session.commit()
 
-    c = session.get(IntervalModel, 1)  # type: ignore
-    c.field = timedelta(days=5)
+    c2 = session.query(IntervalModel).get(1)
+    assert c2
+    c2.field = timedelta(days=5)
     session.flush()
     session.commit()
 
